@@ -4,9 +4,9 @@ from .controller import (  # noqa
     Controller,
     CreateController,
     CreateUpdateController,
-    CRUDController,
     DestroyController,
     ListController,
+    ModelController,
     ReadOnlyController,
     RetrieveController,
     UpdateController,
