@@ -2,10 +2,10 @@ from typing import TYPE_CHECKING
 
 from werkzeug.local import LocalProxy
 
-from .context import _app_ctx_stack, _request_ctx_stack
+from .context import _app_ctx_stack, _request_ctx_stack, _websocket_ctx_stack
 
 if TYPE_CHECKING:
-    from fastapi import Request
+    from fastapi import Request, WebSocket
     from starlette.datastructures import State
 
     from .app import Fastack
@@ -13,7 +13,7 @@ if TYPE_CHECKING:
 
 def _get_state() -> "State":
     state = None
-    if request is None and current_app is not None:
+    if current_app and not request:
         state = current_app.state
     else:
         state = request.state
@@ -22,4 +22,5 @@ def _get_state() -> "State":
 
 current_app: "Fastack" = LocalProxy(lambda: _app_ctx_stack.top)
 request: "Request" = LocalProxy(lambda: _request_ctx_stack.top)
+websocket: "WebSocket" = LocalProxy(lambda: _websocket_ctx_stack.top)
 state: "State" = LocalProxy(lambda: _get_state())
